This is support for the smoother function lrs() an interface for Brad Efron and Trevor Hastie for lars() function.
It is not intended to be called directly by users.
gamlss.lrs(x, y, w, xeval = NULL, ...)the explanatory variables
iterative y variable
iterative weights
if xeval=TRUE then predicion is used
for extra arguments
No return value, called for GAMLSS lrs procedure.
Rigby, R. A. and Stasinopoulos D. M. (2005). Generalized additive models for location, scale and shape,(with discussion), Appl. Statist., 54, part 3, pp 507-554.
Rigby R.A., Stasinopoulos D. M., Heller G., and De Bastiani F., (2019) Distributions for Modeling Location, Scale and Shape: Using GAMLSS in R, Chapman and Hall/CRC.
Ripley, B. D. (1996) Pattern Recognition and Neural Networks. Cambridge.
Stasinopoulos D. M. Rigby R.A. (2007) Generalized additive models for location scale and shape (GAMLSS) in R. Journal of Statistical Software, Vol. 23, Issue 7, Dec 2007, https://www.jstatsoft.org/v23/i07.
Stasinopoulos D. M., Rigby R.A., Heller G., Voudouris V., and De Bastiani F., (2017) Flexible Regression and Smoothing: Using GAMLSS in R, Chapman and Hall/CRC.
(see also https://www.gamlss.com/).
Venables, W. N. and Ripley, B. D. (2002) Modern Applied Statistics with S. Fourth edition. Springer.